@@ -4,19 +4,21 @@ import (
 	"bufio"
 	"bytes"
 	"errors"
-	"os/exec"
 	"strings"
 	"testing"
+
+	"github.com/bmf-san/ggc/v5/git"
 )
 
 // mockBranchGitClient is a mock implementation of git.Clienter for branch tests
 type mockBranchGitClient struct {
-	mockGitClient
 	getCurrentBranchCalled bool
 	currentBranch          string
 	err                    error
 	listLocalBranches      func() ([]string, error)
 	listRemoteBranches     func() ([]string, error)
+	mergedBranches         []string
+	checkoutNewBranchError bool
 }
 
 func (m *mockBranchGitClient) GetCurrentBranch() (string, error) {
@@ -38,30 +40,156 @@ func (m *mockBranchGitClient) ListRemoteBranches() ([]string, error) {
 	return []string{"origin/main", "origin/feature/test"}, nil
 }
 
-// define other functions as nil except branch testing ones
-func (m *mockBranchGitClient) LogGraph() error {
+// Repository Information methods
+func (m *mockBranchGitClient) GetBranchName() (string, error) { return "main", nil }
+func (m *mockBranchGitClient) GetGitStatus() (string, error)  { return "", nil }
+
+// Status Operations methods
+func (m *mockBranchGitClient) Status() (string, error)               { return "", nil }
+func (m *mockBranchGitClient) StatusShort() (string, error)          { return "", nil }
+func (m *mockBranchGitClient) StatusWithColor() (string, error)      { return "", nil }
+func (m *mockBranchGitClient) StatusShortWithColor() (string, error) { return "", nil }
+
+// Staging Operations methods
+func (m *mockBranchGitClient) Add(_ ...string) error { return nil }
+func (m *mockBranchGitClient) AddInteractive() error { return nil }
+
+// Commit Operations methods
+func (m *mockBranchGitClient) Commit(_ string) error                 { return nil }
+func (m *mockBranchGitClient) CommitAmend() error                    { return nil }
+func (m *mockBranchGitClient) CommitAmendNoEdit() error              { return nil }
+func (m *mockBranchGitClient) CommitAmendWithMessage(_ string) error { return nil }
+func (m *mockBranchGitClient) CommitAllowEmpty() error               { return nil }
+
+// Diff Operations methods
+func (m *mockBranchGitClient) Diff() (string, error)       { return "", nil }
+func (m *mockBranchGitClient) DiffStaged() (string, error) { return "", nil }
+func (m *mockBranchGitClient) DiffHead() (string, error)   { return "", nil }
+
+// Branch Operations methods
+func (m *mockBranchGitClient) CheckoutNewBranch(branchName string) error {
+	if m.checkoutNewBranchError {
+		return errors.New("exit status 1")
+	}
+	// Check if branch already exists
+	if branchName == "main" {
+		return errors.New("fatal: a branch named 'main' already exists")
+	}
 	return nil
 }
+func (m *mockBranchGitClient) CheckoutBranch(_ string) error { return nil }
+func (m *mockBranchGitClient) CheckoutNewBranchFromRemote(_, _ string) error {
+	return nil
+}
+func (m *mockBranchGitClient) DeleteBranch(_ string) error { return nil }
+func (m *mockBranchGitClient) ListMergedBranches() ([]string, error) {
+	if m.mergedBranches != nil {
+		return m.mergedBranches, nil
+	}
+	return []string{}, nil
+}
+func (m *mockBranchGitClient) RenameBranch(_, _ string) error      { return nil }
+func (m *mockBranchGitClient) MoveBranch(_, _ string) error        { return nil }
+func (m *mockBranchGitClient) SetUpstreamBranch(_, _ string) error { return nil }
+func (m *mockBranchGitClient) GetBranchInfo(branch string) (*git.BranchInfo, error) {
+	// Provide simple consistent info
+	bi := &git.BranchInfo{
+		Name:            branch,
+		IsCurrentBranch: branch == "main",
+		Upstream:        "origin/" + branch,
+		AheadBehind:     "ahead 1",
+		LastCommitSHA:   "abc1234",
+		LastCommitMsg:   "Test commit",
+	}
+	return bi, nil
+}
+func (m *mockBranchGitClient) ListBranchesVerbose() ([]git.BranchInfo, error) {
+	return []git.BranchInfo{
+		{Name: "main", IsCurrentBranch: true, Upstream: "origin/main", LastCommitSHA: "1234567", LastCommitMsg: "msg"},
+		{Name: "feature", IsCurrentBranch: false, Upstream: "origin/feature", LastCommitSHA: "89abcde", LastCommitMsg: "msg2"},
+	}, nil
+}
+func (m *mockBranchGitClient) SortBranches(_ string) ([]string, error) {
+	return []string{"a", "b"}, nil
+}
+func (m *mockBranchGitClient) BranchesContaining(_ string) ([]string, error) {
+	return []string{"main", "feature"}, nil
+}
 
-func (m *mockBranchGitClient) RestoreAll() error {
-	return nil
+// Remote Operations methods
+func (m *mockBranchGitClient) Push(_ bool) error              { return nil }
+func (m *mockBranchGitClient) Pull(_ bool) error              { return nil }
+func (m *mockBranchGitClient) Fetch(_ bool) error             { return nil }
+func (m *mockBranchGitClient) RemoteList() error              { return nil }
+func (m *mockBranchGitClient) RemoteAdd(_, _ string) error    { return nil }
+func (m *mockBranchGitClient) RemoteRemove(_ string) error    { return nil }
+func (m *mockBranchGitClient) RemoteSetURL(_, _ string) error { return nil }
+
+// Tag Operations methods
+func (m *mockBranchGitClient) TagList(_ []string) error              { return nil }
+func (m *mockBranchGitClient) TagCreate(_, _ string) error           { return nil }
+func (m *mockBranchGitClient) TagCreateAnnotated(_, _ string) error  { return nil }
+func (m *mockBranchGitClient) TagDelete(_ []string) error            { return nil }
+func (m *mockBranchGitClient) TagPush(_, _ string) error             { return nil }
+func (m *mockBranchGitClient) TagPushAll(_ string) error             { return nil }
+func (m *mockBranchGitClient) TagShow(_ string) error                { return nil }
+func (m *mockBranchGitClient) GetLatestTag() (string, error)         { return "v1.0.0", nil }
+func (m *mockBranchGitClient) TagExists(_ string) bool               { return false }
+func (m *mockBranchGitClient) GetTagCommit(_ string) (string, error) { return "abc123", nil }
+
+// Log Operations methods
+func (m *mockBranchGitClient) LogSimple() error                       { return nil }
+func (m *mockBranchGitClient) LogGraph() error                        { return nil }
+func (m *mockBranchGitClient) LogOneline(_, _ string) (string, error) { return "", nil }
+
+// Rebase Operations methods
+func (m *mockBranchGitClient) RebaseInteractive(_ int) error { return nil }
+func (m *mockBranchGitClient) GetUpstreamBranch(_ string) (string, error) {
+	return "origin/main", nil
 }
 
-func (m *mockBranchGitClient) RestoreAllStaged() error {
-	return nil
-}
+// Stash Operations methods
+func (m *mockBranchGitClient) Stash() error               { return nil }
+func (m *mockBranchGitClient) StashList() (string, error) { return "", nil }
+func (m *mockBranchGitClient) StashShow(_ string) error   { return nil }
+func (m *mockBranchGitClient) StashApply(_ string) error  { return nil }
+func (m *mockBranchGitClient) StashPop(_ string) error    { return nil }
+func (m *mockBranchGitClient) StashDrop(_ string) error   { return nil }
+func (m *mockBranchGitClient) StashClear() error          { return nil }
 
-func (m *mockBranchGitClient) RestoreStaged(...string) error {
-	return nil
-}
+// Reset and Clean Operations methods
+func (m *mockBranchGitClient) ResetHardAndClean() error         { return nil }
+func (m *mockBranchGitClient) ResetHard(_ string) error         { return nil }
+func (m *mockBranchGitClient) CleanFiles() error                { return nil }
+func (m *mockBranchGitClient) CleanDirs() error                 { return nil }
+func (m *mockBranchGitClient) CleanDryRun() (string, error)     { return "", nil }
+func (m *mockBranchGitClient) CleanFilesForce(_ []string) error { return nil }
 
-func (m *mockBranchGitClient) RestoreWorkingDir(...string) error {
-	return nil
+// Utility Operations methods
+func (m *mockBranchGitClient) ListFiles() (string, error) { return "", nil }
+func (m *mockBranchGitClient) GetUpstreamBranchName(_ string) (string, error) {
+	return "origin/main", nil
 }
+func (m *mockBranchGitClient) GetAheadBehindCount(_, _ string) (string, error) {
+	return "0	0", nil
+}
+func (m *mockBranchGitClient) GetVersion() (string, error)    { return "test-version", nil }
+func (m *mockBranchGitClient) GetCommitHash() (string, error) { return "test-commit", nil }
 
-func (m *mockBranchGitClient) RestoreFromCommit(string, ...string) error {
-	return nil
-}
+// Restore Operations methods
+func (m *mockBranchGitClient) RestoreWorkingDir(_ ...string) error           { return nil }
+func (m *mockBranchGitClient) RestoreStaged(_ ...string) error               { return nil }
+func (m *mockBranchGitClient) RestoreFromCommit(_ string, _ ...string) error { return nil }
+func (m *mockBranchGitClient) RestoreAll() error                             { return nil }
+func (m *mockBranchGitClient) RestoreAllStaged() error                       { return nil }
+
+func (m *mockBranchGitClient) RevParseVerify(string) bool { return false }
+
+// Config Operations
+func (m *mockBranchGitClient) ConfigGet(_ string) (string, error)       { return "", nil }
+func (m *mockBranchGitClient) ConfigSet(_, _ string) error              { return nil }
+func (m *mockBranchGitClient) ConfigGetGlobal(_ string) (string, error) { return "", nil }
+func (m *mockBranchGitClient) ConfigSetGlobal(_, _ string) error        { return nil }
 
 func TestBrancher_Branch_Current(t *testing.T) {
 	var buf bytes.Buffer
@@ -111,8 +239,8 @@ func TestBrancher_Branch_Checkout(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("1\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("1\n")),
 	}
 	brancher.Branch([]string{"checkout"})
 
@@ -129,8 +257,8 @@ func TestBrancher_Branch_CheckoutRemote(t *testing.T) {
 		gitClient:    &mockBranchGitClient{},
 		outputWriter: &buf,
 		helper:       NewHelper(),
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("1\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("1\n")),
 	}
 	brancher.helper.outputWriter = &buf
 
@@ -148,8 +276,8 @@ func TestBrancher_Branch_Delete(t *testing.T) {
 		gitClient:    &mockBranchGitClient{},
 		outputWriter: &buf,
 		helper:       NewHelper(),
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("1\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("1\n")),
 	}
 	brancher.helper.outputWriter = &buf
 
@@ -164,19 +292,14 @@ func TestBrancher_Branch_Delete(t *testing.T) {
 func TestBrancher_Branch_DeleteMerged(t *testing.T) {
 	var buf bytes.Buffer
 	mockClient := &mockBranchGitClient{
-		currentBranch: "main",
+		currentBranch:  "main",
+		mergedBranches: []string{"feature/old", "feature/completed"},
 	}
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
 		helper:       NewHelper(),
-		execCommand: func(name string, args ...string) *exec.Cmd {
-			if name == "git" && len(args) > 0 && args[0] == "branch" && args[1] == "--merged" {
-				cmd := exec.Command("echo", "  main\n  feature/merged")
-				return cmd
-			}
-			return exec.Command("echo")
-		},
+
 		inputReader: bufio.NewReader(strings.NewReader("1\n")),
 	}
 	brancher.helper.outputWriter = &buf
@@ -269,8 +392,8 @@ func TestBrancher_branchCheckout_InvalidNumber(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("invalid\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("invalid\n")),
 	}
 	brancher.branchCheckout()
 
@@ -290,8 +413,8 @@ func TestBrancher_branchDelete_Success(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("1 2\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("1 2\n")),
 	}
 
 	brancher.branchDelete()
@@ -315,8 +438,8 @@ func TestBrancher_branchDelete_All(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("all\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("all\n")),
 	}
 
 	brancher.branchDelete()
@@ -337,8 +460,8 @@ func TestBrancher_branchDelete_Cancel(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("\n")),
 	}
 
 	brancher.branchDelete()
@@ -392,18 +515,13 @@ func TestBrancher_branchDelete_NoBranches(t *testing.T) {
 func TestBrancher_branchDeleteMerged_Success(t *testing.T) {
 	var buf bytes.Buffer
 	mockClient := &mockBranchGitClient{
-		currentBranch: "main",
+		currentBranch:  "main",
+		mergedBranches: []string{"feature/old", "feature/completed"},
 	}
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand: func(name string, args ...string) *exec.Cmd {
-			if name == "git" && len(args) > 0 && args[0] == "branch" && args[1] == "--merged" {
-				cmd := exec.Command("echo", "  main\n  feature/merged\n  bugfix/old")
-				return cmd
-			}
-			return exec.Command("echo")
-		},
+
 		inputReader: bufio.NewReader(strings.NewReader("1 2\n")),
 	}
 
@@ -418,18 +536,13 @@ func TestBrancher_branchDeleteMerged_Success(t *testing.T) {
 func TestBrancher_branchDeleteMerged_All(t *testing.T) {
 	var buf bytes.Buffer
 	mockClient := &mockBranchGitClient{
-		currentBranch: "main",
+		currentBranch:  "main",
+		mergedBranches: []string{"feature/old", "feature/completed", "hotfix/bug"},
 	}
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand: func(name string, args ...string) *exec.Cmd {
-			if name == "git" && len(args) > 0 && args[0] == "branch" && args[1] == "--merged" {
-				cmd := exec.Command("echo", "  main\n  feature/merged")
-				return cmd
-			}
-			return exec.Command("echo")
-		},
+
 		inputReader: bufio.NewReader(strings.NewReader("all\n")),
 	}
 
@@ -444,18 +557,13 @@ func TestBrancher_branchDeleteMerged_All(t *testing.T) {
 func TestBrancher_branchDeleteMerged_Cancel(t *testing.T) {
 	var buf bytes.Buffer
 	mockClient := &mockBranchGitClient{
-		currentBranch: "main",
+		currentBranch:  "main",
+		mergedBranches: []string{"feature/old", "feature/completed"},
 	}
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand: func(name string, args ...string) *exec.Cmd {
-			if name == "git" && len(args) > 0 && args[0] == "branch" && args[1] == "--merged" {
-				cmd := exec.Command("echo", "  main\n  feature/merged")
-				return cmd
-			}
-			return exec.Command("echo")
-		},
+
 		inputReader: bufio.NewReader(strings.NewReader("\n")),
 	}
 
@@ -493,13 +601,6 @@ func TestBrancher_branchDeleteMerged_NoMergedBranches(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand: func(name string, args ...string) *exec.Cmd {
-			if name == "git" && len(args) > 0 && args[0] == "branch" && args[1] == "--merged" {
-				cmd := exec.Command("echo", "  main")
-				return cmd
-			}
-			return exec.Command("echo")
-		},
 	}
 
 	brancher.branchDeleteMerged()
@@ -515,8 +616,8 @@ func TestBrancher_branchCheckoutRemote_Success(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    &mockBranchGitClient{},
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("2\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("2\n")),
 	}
 
 	brancher.branchCheckoutRemote()
@@ -535,8 +636,8 @@ func TestBrancher_branchCheckoutRemote_InvalidNumber(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    &mockBranchGitClient{},
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("invalid\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("invalid\n")),
 	}
 
 	brancher.branchCheckoutRemote()
@@ -557,8 +658,8 @@ func TestBrancher_branchCheckoutRemote_InvalidBranchName(t *testing.T) {
 	brancher := &Brancher{
 		gitClient:    mockClient,
 		outputWriter: &buf,
-		execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-		inputReader:  bufio.NewReader(strings.NewReader("1\n")),
+
+		inputReader: bufio.NewReader(strings.NewReader("1\n")),
 	}
 
 	brancher.branchCheckoutRemote()
@@ -569,6 +670,27 @@ func TestBrancher_branchCheckoutRemote_InvalidBranchName(t *testing.T) {
 	}
 }
 
+func TestBrancher_branchCheckoutRemote_EmptyLocalFromRemote(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{
+		listRemoteBranches: func() ([]string, error) {
+			return []string{"remote/"}, nil
+		},
+	}
+	brancher := &Brancher{
+		gitClient:    mockClient,
+		outputWriter: &buf,
+		inputReader:  bufio.NewReader(strings.NewReader("1\n")),
+	}
+
+	brancher.branchCheckoutRemote()
+
+	output := buf.String()
+	if !strings.Contains(output, "Invalid remote branch name.") {
+		t.Error("Expected invalid remote branch name message for empty local name")
+	}
+}
+
 func TestBrancher_Branch_Create(t *testing.T) {
 	tests := []struct {
 		name           string
@@ -580,7 +702,7 @@ func TestBrancher_Branch_Create(t *testing.T) {
 		{
 			name:           "Success: Create new branch",
 			input:          "feature/test\n",
-			expectedOutput: "Enter new branch name: \n",
+			expectedOutput: "Enter new branch name: ",
 			cmdOutput:      "",
 			cmdError:       false,
 		},
@@ -604,15 +726,9 @@ func TestBrancher_Branch_Create(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			var buf bytes.Buffer
 			brancher := &Brancher{
-				gitClient:    &mockBranchGitClient{},
+				gitClient:    &mockBranchGitClient{checkoutNewBranchError: tt.cmdError},
 				outputWriter: &buf,
 				inputReader:  bufio.NewReader(strings.NewReader(tt.input)),
-				execCommand: func(_ string, _ ...string) *exec.Cmd {
-					if tt.cmdError {
-						return exec.Command("false")
-					}
-					return exec.Command("echo", tt.cmdOutput)
-				},
 			}
 
 			brancher.Branch([]string{"create"})
@@ -631,18 +747,12 @@ func TestBrancher_branchCreate_ExistingBranch(t *testing.T) {
 		gitClient:    &mockBranchGitClient{},
 		outputWriter: &buf,
 		inputReader:  bufio.NewReader(strings.NewReader("main\n")),
-		execCommand: func(_ string, _ ...string) *exec.Cmd {
-			// Set up git command to return error
-			cmd := exec.Command("echo", "fatal: A branch named 'main' already exists.")
-			cmd.Stderr = cmd.Stdout
-			return cmd
-		},
 	}
 
 	brancher.Branch([]string{"create"})
 
 	output := buf.String()
-	expectedOutput := "Enter new branch name: fatal: A branch named 'main' already exists.\n"
+	expectedOutput := "Enter new branch name: Error: failed to create and checkout branch: fatal: a branch named 'main' already exists\n"
 	if output != expectedOutput {
 		t.Errorf("unexpected output:\ngot:  %q\nwant: %q", output, expectedOutput)
 	}
@@ -698,8 +808,8 @@ func TestBrancher_Branch_BoundaryInputValues(t *testing.T) {
 			brancher := &Brancher{
 				gitClient:    mockClient,
 				outputWriter: &buf,
-				execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-				inputReader:  bufio.NewReader(strings.NewReader(tt.input)),
+
+				inputReader: bufio.NewReader(strings.NewReader(tt.input)),
 			}
 
 			brancher.branchCheckout()
@@ -728,8 +838,8 @@ func TestBrancher_Branch_BoundaryBranchNames(t *testing.T) {
 		{
 			name:         "Maximum length branch name",
 			branchName:   strings.Repeat("a", 255),
-			expectedPass: false,
-			description:  "Very long branch name",
+			expectedPass: true,
+			description:  "Long branch name allowed by git",
 		},
 		{
 			name:         "Branch name with dots",
@@ -759,7 +869,7 @@ func TestBrancher_Branch_BoundaryBranchNames(t *testing.T) {
 			name:         "Branch name starting with dot",
 			branchName:   ".test",
 			expectedPass: false,
-			description:  "Invalid: starts with dot",
+			description:  "Leading dot is rejected by git",
 		},
 		{
 			name:         "Branch name ending with dot",
@@ -782,8 +892,8 @@ func TestBrancher_Branch_BoundaryBranchNames(t *testing.T) {
 		{
 			name:         "Branch name with special characters",
 			branchName:   "test@#$%",
-			expectedPass: false,
-			description:  "Invalid: special characters",
+			expectedPass: true,
+			description:  "Allowed by git check-ref-format (no forbidden sequences)",
 		},
 		{
 			name:         "Branch name with control characters",
@@ -800,12 +910,6 @@ func TestBrancher_Branch_BoundaryBranchNames(t *testing.T) {
 				gitClient:    &mockBranchGitClient{},
 				outputWriter: &buf,
 				inputReader:  bufio.NewReader(strings.NewReader(tt.branchName + "\n")),
-				execCommand: func(_ string, _ ...string) *exec.Cmd {
-					if tt.expectedPass {
-						return exec.Command("echo")
-					}
-					return exec.Command("false")
-				},
 			}
 
 			brancher.branchCreate()
@@ -853,7 +957,7 @@ func TestBrancher_Branch_BoundaryUserInput(t *testing.T) {
 		{
 			name:     "Very long input",
 			input:    strings.Repeat("a", 1000) + "\n",
-			expected: "Error:",
+			expected: "", // Git allows long branch names
 		},
 		{
 			name:     "Input with trailing spaces",
@@ -868,7 +972,7 @@ func TestBrancher_Branch_BoundaryUserInput(t *testing.T) {
 		{
 			name:     "Unicode characters",
 			input:    "brαnch\n",
-			expected: "Error:",
+			expected: "", // Git allows UTF-8 branch names
 		},
 		{
 			name:     "Mixed case input",
@@ -884,12 +988,6 @@ func TestBrancher_Branch_BoundaryUserInput(t *testing.T) {
 				gitClient:    &mockBranchGitClient{},
 				outputWriter: &buf,
 				inputReader:  bufio.NewReader(strings.NewReader(tt.input)),
-				execCommand: func(_ string, _ ...string) *exec.Cmd {
-					if strings.Contains(tt.expected, "Error:") {
-						return exec.Command("false")
-					}
-					return exec.Command("echo")
-				},
 			}
 
 			brancher.branchCreate()
@@ -948,8 +1046,8 @@ func TestBrancher_Branch_BoundaryListOperations(t *testing.T) {
 			brancher := &Brancher{
 				gitClient:    mockClient,
 				outputWriter: &buf,
-				execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-				inputReader:  bufio.NewReader(strings.NewReader(tt.input)),
+
+				inputReader: bufio.NewReader(strings.NewReader(tt.input)),
 			}
 
 			brancher.branchCheckout()
@@ -1018,8 +1116,8 @@ func TestBrancher_Branch_BoundaryDeleteOperations(t *testing.T) {
 			brancher := &Brancher{
 				gitClient:    mockClient,
 				outputWriter: &buf,
-				execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-				inputReader:  bufio.NewReader(strings.NewReader(tt.input)),
+
+				inputReader: bufio.NewReader(strings.NewReader(tt.input)),
 			}
 
 			brancher.branchDelete()
@@ -1070,8 +1168,8 @@ func TestBrancher_Branch_BoundaryRemoteOperations(t *testing.T) {
 			brancher := &Brancher{
 				gitClient:    mockClient,
 				outputWriter: &buf,
-				execCommand:  func(_ string, _ ...string) *exec.Cmd { return exec.Command("echo") },
-				inputReader:  bufio.NewReader(strings.NewReader(tt.input)),
+
+				inputReader: bufio.NewReader(strings.NewReader(tt.input)),
 			}
 
 			brancher.branchDelete()
