@@ -2,23 +2,20 @@ package cmd
 
 import (
 	"fmt"
-	"os/exec"
 	"strings"
 
-	"github.com/bmf-san/ggc/v4/git"
+	"github.com/bmf-san/ggc/v5/git"
 )
 
 // Completer handles dynamic completion for subcommands/args
 type Completer struct {
-	gitClient   git.Clienter
-	execCommand func(name string, arg ...string) *exec.Cmd
+	gitClient git.Clienter
 }
 
 // NewCompleter creates a new Completer.
-var NewCompleter = func() *Completer {
+var NewCompleter = func(client git.Clienter) *Completer {
 	return &Completer{
-		gitClient:   git.NewClient(),
-		execCommand: exec.Command,
+		gitClient: client,
 	}
 }
 
@@ -31,7 +28,23 @@ func (c *Completer) Complete(args []string) {
 	case "branch":
 		if len(args) == 1 {
 			// Suggest subcommand candidates
-			subs := []string{"current", "checkout", "checkout-remote", "create", "delete", "delete-merged"}
+			subs := []string{
+				"current",
+				"checkout",
+				"checkout-remote",
+				"create",
+				"delete",
+				"delete-merged",
+				// Enhanced branch management
+				"rename",
+				"move",
+				"set-upstream",
+				"info",
+				"list",
+				"list --verbose",
+				"sort",
+				"contains",
+			}
 			for _, s := range subs {
 				fmt.Println(s)
 			}
@@ -47,12 +60,11 @@ func (c *Completer) Complete(args []string) {
 		}
 	case "files":
 		// Get list of files managed by git ls-files
-		cmd := c.execCommand("git", "ls-files")
-		out, err := cmd.Output()
+		out, err := c.gitClient.ListFiles()
 		if err != nil {
 			return
 		}
-		files := strings.Split(strings.TrimSpace(string(out)), "\n")
+		files := strings.Split(strings.TrimSpace(out), "\n")
 		for _, f := range files {
 			fmt.Println(f)
 		}
