@@ -4,9 +4,10 @@ package main
 import (
 	"os"
 
-	"github.com/bmf-san/ggc/v4/cmd"
-	"github.com/bmf-san/ggc/v4/config"
-	"github.com/bmf-san/ggc/v4/router"
+	"github.com/bmf-san/ggc/v5/cmd"
+	"github.com/bmf-san/ggc/v5/config"
+	"github.com/bmf-san/ggc/v5/git"
+	"github.com/bmf-san/ggc/v5/router"
 )
 
 var (
@@ -20,10 +21,10 @@ func GetVersionInfo() (string, string) {
 }
 
 func main() {
-	cm := config.NewConfigManager()
+	cm := config.NewConfigManager(git.NewClient())
 	cm.LoadConfig()
 	cmd.SetVersionGetter(GetVersionInfo)
-	c := cmd.NewCmd()
+	c := cmd.NewCmd(git.NewClient())
 	r := router.NewRouter(c, cm)
 	r.Route(os.Args[1:])
 }
